package javax.management.remote.rmi;

import java.security.ProtectionDomain;

class NoCallStackClassLoader extends ClassLoader
{
    private final String[] classNames;
    private final byte[][] byteCodes;
    private final String[] referencedClassNames;
    private final ClassLoader referencedClassLoader;
    private final ProtectionDomain protectionDomain;
    
    public NoCallStackClassLoader(String s, byte[] array, String[] array2, ClassLoader classLoader, ProtectionDomain protectionDomain) {
        this(new String[] { s }, new byte[][] { array }, array2, classLoader, protectionDomain);
    }
    
    public NoCallStackClassLoader(String[] classNames, byte[][] byteCodes, String[] referencedClassNames, ClassLoader referencedClassLoader, ProtectionDomain protectionDomain) {
        super(null);
        if (classNames == null || classNames.length == 0 || byteCodes == null || classNames.length != byteCodes.length || referencedClassNames == null || protectionDomain == null) {
            throw new IllegalArgumentException();
        }
        int i = 0;
        while (i < classNames.length) {
            if (classNames[i] == null || byteCodes[i] == null) {
                throw new IllegalArgumentException();
            }
            ++i;
        }
        int j = 0;
        while (j < referencedClassNames.length) {
            if (referencedClassNames[j] == null) {
                throw new IllegalArgumentException();
            }
            ++j;
        }
        this.classNames = classNames;
        this.byteCodes = byteCodes;
        this.referencedClassNames = referencedClassNames;
        this.referencedClassLoader = referencedClassLoader;
        this.protectionDomain = protectionDomain;
        return;
    }
    
    @Override
    protected Class<?> findClass(String s) throws ClassNotFoundException {
        int i = 0;
        while (i < this.classNames.length) {
            if (s.equals(this.classNames[i])) {
                return this.defineClass(this.classNames[i], this.byteCodes[i], 0, this.byteCodes[i].length, this.protectionDomain);
            }
            ++i;
        }
        if (this.referencedClassLoader != null) {
            int j = 0;
            while (j < this.referencedClassNames.length) {
                if (s.equals(this.referencedClassNames[j])) {
                    return this.referencedClassLoader.loadClass(s);
                }
                ++j;
            }
        }
        throw new ClassNotFoundException(s);
    }
    
    public static byte[] stringToBytes(String s) {
        int length = s.length();
        byte[] array = new byte[length];
        for (int i = 0; i < length; ++i) {
            array[i] = (byte)s.charAt(i);
        }
        return array;
    }
}
